@@ -1,13 +1,4 @@
 from django.conf import settings
-
-
-try:
-    from django.contrib.auth import get_user_model
-    User = get_user_model()
-except ImportError:
-    from django.contrib.auth.models import User
-
-
 from django.db.models.fields.related import ForeignKey, ManyToOneRel
 from cuser.middleware import CuserMiddleware
 
@@ -23,15 +14,15 @@ if 'south' in settings.INSTALLED_APPS:
 
 
 class CurrentUserField(ForeignKey):
-    def __init__(self, to_field=None, rel_class=ManyToOneRel, to=User,
-                 **kwargs):
+    def __init__(self, to_field=None, rel_class=ManyToOneRel,
+                 to=settings.AUTH_USER_MODEL, **kwargs):
         self.add_only = kwargs.pop('add_only', False)
         kwargs.update({
-          'editable': False,
-          'null': True,
-          'rel_class': rel_class,
-          'to': to,
-          'to_field': to_field,
+            'editable': False,
+            'null': True,
+            'rel_class': rel_class,
+            'to': to,
+            'to_field': to_field,
         })
         super(CurrentUserField, self).__init__(**kwargs)
 
@@ -41,4 +32,5 @@ class CurrentUserField(ForeignKey):
             if user:
                 setattr(model_instance, self.attname, user.pk)
                 return user.pk
+
         return super(CurrentUserField, self).pre_save(model_instance, add)
